==> haskell-doctemplates-0.11.0.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctemplates
version:              0.11.0.1
visibility:           public
id:                   doctemplates-0.11.0.1-D2bzCjhJH2P9CRxUri95id
key:                  doctemplates-0.11.0.1-D2bzCjhJH2P9CRxUri95id
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  420fc09933aa1e474d46d26c35a8cd99
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctemplates-0.11.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctemplates-0.11.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctemplates-0.11.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.11.0.1-D2bzCjhJH2P9CRxUri95id
depends:
    aeson-2.1.2.1-nFo3VMHABFBaVDPPKfnuT base-4.17.2.1 containers-0.6.7
    doclayout-0.4.0.1-ARwSAVedBShABEvMPzkmA7 filepath-1.4.2.2 mtl-2.2.2
    parsec-3.1.16.1 safe-0.3.21-9QjteULaG8kEYP4tViLK83
    scientific-0.3.7.0-H4Og6N92k1lGQSMIPZo0fR text-2.0.2
    text-conversions-0.3.1.1-3p0MFx3N4QbJGcnPkOLdOf
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.11.0.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctemplates
version:              0.11.0.1
visibility:           public
id:                   doctemplates-0.11.0.1-7VGILvfYFiJ1ePdUfTksnz
key:                  doctemplates-0.11.0.1-7VGILvfYFiJ1ePdUfTksnz
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  b1ec8da6badbeb1468fa8bf1a681b7da
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctemplates-0.11.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctemplates-0.11.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctemplates-0.11.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.11.0.1-7VGILvfYFiJ1ePdUfTksnz
depends:
    aeson-2.1.2.1-4cRYi3WcVwTKRqMhXUztfB base-4.17.2.1 containers-0.6.7
    doclayout-0.4.0.1-DYIG4TLCHPj7OttFZFQOk4 filepath-1.4.2.2 mtl-2.2.2
    parsec-3.1.16.1 safe-0.3.21-I6HqCqj5Wiu30StmjnRW6G
    scientific-0.3.7.0-K2KPplW6Nka7Ws1cS3R2Yx text-2.0.2
    text-conversions-0.3.1.1-5c9zbw9HdSM4ewm6VstEhi
    vector-0.13.2.0-5H8NMvQc0Ab8bNH9ZMgAUW

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
